Index: /trunk/src/tropflux_init.pro
===================================================================
--- /trunk/src/tropflux_init.pro	(revision 44)
+++ /trunk/src/tropflux_init.pro	(revision 45)
@@ -3,7 +3,7 @@
 ; .. _tropflux_init.pro:
 ;
-; =================
-; tropflux_init.pro
-; =================
+; ==========================================
+; tropflux_init.pro -- init SAXO environment
+; ==========================================
 ;
 ; DESCRIPTION
@@ -11,6 +11,4 @@
 ;
 ; This is the SAXO initialisation file.
-; it defines the !path and the defaut values of some of the common variables
-;
 ;
 ; It ++::
@@ -42,4 +40,14 @@
 ; ==========
 ;
+; $URL$
+;
+; - fplod 20110413T151541Z cratos.locean-ipsl.upmc.fr (Linux)
+;
+;   * fix uncompleted replacement SAXO_SRC by SAXO_DIR
+;
+; - fplod 20110413T070801Z aedon.locean-ipsl.upmc.fr (Darwin)
+;
+;   * replace SAXO_SRC by SAXO_DIR
+;
 ; - fplod 20110411T074056Z aedon.locean-ipsl.upmc.fr (Darwin)
 ;
@@ -54,5 +62,5 @@
 ; 
 ; SAXO environment
-saxo_src_env=GETENV('SAXO_SRC')
+saxo_dir_env=GETENV('SAXO_DIR')
 ; tropflux environment
 @cm_tropflux
@@ -60,9 +68,9 @@
 tropflux_id_env=GETENV('TROPFLUX_ID')
 tropflux_od_env=GETENV('TROPFLUX_OD')
-
+;
 ; path definition
 ;
 !path = expand_path('+' + tropflux_env + '/src') $
-      + path_sep(/search_path) + expand_path('+' + saxo_src_env) $
+      + path_sep(/search_path) + expand_path('+' + saxo_dir_env) $
       + path_sep(/search_path) + expand_path('+' + !dir)
 ;
Index: /trunk/src/tropflux_profile.sh
===================================================================
--- /trunk/src/tropflux_profile.sh	(revision 44)
+++ /trunk/src/tropflux_profile.sh	(revision 45)
@@ -1,3 +1,3 @@
-#! /bin/sh
+#! /bin/sh -x
 #+
 #
@@ -15,9 +15,9 @@
 # Online usage::
 #
 #  $ . ./tropflux_profile.sh -d directory -i indir -o outdir -t tempdir -s saxo_src
 #
 # In ${HOME}/.profile, add the following line::
 #
 #  . tropflux_profile.sh -d directory  -i indir -o outdir -t tempdir -s saxo_src
 #
 # DESCRIPTION
@@ -28,5 +28,5 @@
 # .. option:: -o  <outdir>
 # .. option:: -t  <tempdir>
-# .. option:: -s  <saxo_src>
+# .. option:: -s  <saxo_dir>
 #
 # define TROPFLUX environment
@@ -40,5 +40,5 @@
 # ${TROPFLUX_OD} is the directory where output files will be written.
 #
 # ${SAXO_SRC} is the base directory of SAXO tools
 #
 # PATH is completed with ${TROPFLUX}.
@@ -47,5 +47,7 @@
 # ========
 #
-# :ref:`troflux_init.pro`
+# :ref:`tropflux_init.pro`
+#
+# :ref:`cm_tropflux.pro`
 #
 # EXAMPLES
@@ -60,5 +62,5 @@
 #    -o /usr/temp/${LOGNAME}/tropflux_d/ \
 #    -t /usr/temp/${LOGNAME}/log/ \
-#    -s /usr/home/fplod/SAXO_DIR/SRC/
+#    -s /usr/home/fplod/SAXO_DIR/
 #
 # For fplod on cratos.locean-ipsl.umpc.fr::
@@ -70,5 +72,5 @@
 #    -o /usr/temp/${LOGNAME}/tropflux_d/ \
 #    -t /usr/temp/${LOGNAME}/log/ \
-#    -s ${HOME}/SAXO_DIR/SRC/
+#    -s ${HOME}/SAXO_DIR/
 #
 # For pinsard on camelot.ipsl.polytechnique.fr or merlin15-c.climserv::
@@ -80,5 +82,5 @@
 #   -o /homedata/${LOGNAME}/tropflux_d/ \
 #   -t /homedata/${LOGNAME}/log/
-#   -s ${HOME}/SAXO_DIR/SRC/
+#   -s ${HOME}/SAXO_DIR/
 #
 # TODO
@@ -93,8 +95,10 @@
 # ++ pas de MANPATH defini par défaut sur zeus et cerbere
 #
-# define IDL startup file
-#
 # EVOLUTIONS
 # ==========
+#
+# - fplod 20110413T151541Z cratos.locean-ipsl.upmc.fr (Linux)
+#
+#   * fix uncompleted replacement SAXO_SRC by SAXO_DIR
 #
 # - fplod 20101118T171653Z aedon.locean-ipsl.upmc.fr (Darwin)
@@ -119,5 +123,5 @@
 command=tropflux_profile.sh
 #
-usage=" Usage : ${command} -d directory -i indir -o outdir -t tempdir -s saxo_src"
+usage=" Usage : ${command} -d directory -i indir -o outdir -t tempdir -s saxo_dir"
 #
 set +u
@@ -147,5 +151,5 @@
       -s)
          # directory for SAXO tools
-         saxo_src=${2}
+         saxo_dir=${2}
          shift
       ;;
@@ -280,7 +284,7 @@
 fi
 #
-SAXO_SRC=${saxo_src}
-export SAXO_SRC
-unset saxo_src
+SAXO_DIR=${saxo_dir}
+export SAXO_DIR
+unset saxo_dir
 #
 # end
@@ -15,9 +15,9 @@
 # Online usage::
 #
-#  $ . ./tropflux_profile.sh -d directory -i indir -o outdir -t tempdir -s saxo_src
+#  $ . ./tropflux_profile.sh -d directory -i indir -o outdir -t tempdir -s saxo_dir
 #
 # In ${HOME}/.profile, add the following line::
@@ -15,9 +15,9 @@
 # In ${HOME}/.profile, add the following line::
 #
-#  . tropflux_profile.sh -d directory  -i indir -o outdir -t tempdir -s saxo_src
+#  . tropflux_profile.sh -d directory  -i indir -o outdir -t tempdir -s saxo_dir
 #
 # DESCRIPTION
@@ -40,5 +40,5 @@
 # ${TROPFLUX_OD} is the directory where output files will be written.
 #
-# ${SAXO_SRC} is the base directory of SAXO tools
+# ${SAXO_DIR} is the base directory of SAXO tools
 #
 # PATH is completed with ${TROPFLUX}.
